RealDomain
==========

.. currentmodule:: pqp.data

.. autoclass:: RealDomain
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~RealDomain.describe_assumptions

   .. rubric:: Methods Documentation

   .. automethod:: describe_assumptions
